diff --git a/src/main/java/net/minecraft/client/render/RenderGlobal.java b/src/main/java/net/minecraft/client/render/RenderGlobal.java
index a6214d30d..7e9751ea6 100644
--- a/src/main/java/net/minecraft/client/render/RenderGlobal.java
+++ b/src/main/java/net/minecraft/client/render/RenderGlobal.java
@@ -820,7 +820,7 @@ public class RenderGlobal
 
     public void drawSky(float partialTick)
     {
-        if(mc.theWorld.dimension == Dimension.nether || mc.currentScreen instanceof GuiModelViewer)
+        if(!mc.theWorld.getWorldType().hasSky() || mc.currentScreen instanceof GuiModelViewer)
         {
             return;
         }
@@ -937,7 +937,7 @@ public class RenderGlobal
 
     public void renderClouds(float partialTick)
     {
-        if(mc.theWorld.dimension == Dimension.nether)
+        if(!mc.theWorld.getWorldType().hasClouds())
         {
             return;
         }
diff --git a/src/main/java/net/minecraft/core/data/registry/Registries.java b/src/main/java/net/minecraft/core/data/registry/Registries.java
index f70eeb9bd..3423ad869 100644
--- a/src/main/java/net/minecraft/core/data/registry/Registries.java
+++ b/src/main/java/net/minecraft/core/data/registry/Registries.java
@@ -14,6 +14,7 @@ import net.minecraft.core.world.type.WorldType;
 import net.minecraft.core.world.type.WorldTypes;
 
 import java.util.ArrayList;
+import java.util.Collection;
 import java.util.List;
 
 public class Registries extends Registry<Registry<?>>
@@ -92,6 +93,8 @@ public class Registries extends Registry<Registry<?>>
                 list.add(new ItemStack((Item) item));
             } else if (item instanceof ItemStack) {
                 list.add(new ItemStack((ItemStack) item));
+            } else if (item instanceof Collection<?>) {
+                list.addAll(stackListOf(((Collection<?>) item).toArray(new Object[0])));
             }
         }
         return list;
diff --git a/src/main/java/net/minecraft/core/world/type/WorldType.java b/src/main/java/net/minecraft/core/world/type/WorldType.java
index ac6854457..497061c63 100644
--- a/src/main/java/net/minecraft/core/world/type/WorldType.java
+++ b/src/main/java/net/minecraft/core/world/type/WorldType.java
@@ -60,6 +60,14 @@ public abstract class WorldType
         return defaultSeasonConfig;
     }
 
+    public boolean hasClouds() {
+        return true;
+    }
+
+    public boolean hasSky() {
+        return true;
+    }
+
     public abstract int getMinY();
 
     public abstract int getMaxY();
diff --git a/src/main/java/net/minecraft/core/world/type/WorldTypeNether.java b/src/main/java/net/minecraft/core/world/type/WorldTypeNether.java
index 1a6f9d382..13e559883 100644
--- a/src/main/java/net/minecraft/core/world/type/WorldTypeNether.java
+++ b/src/main/java/net/minecraft/core/world/type/WorldTypeNether.java
@@ -137,4 +137,14 @@ public abstract class WorldTypeNether
     {
         return true;
     }
+
+    @Override
+    public boolean hasClouds() {
+        return false;
+    }
+
+    @Override
+    public boolean hasSky() {
+        return false;
+    }
 }
